Models

Struct Models 

pub struct Models<'a> {
    pub client: &'a Client,
}

Fields

client: &'a Client

Implementations

Source

impl Models<'_>

pub async fn list(&self) -> Result<ListModelResponse, APIError>

Lists the currently available models, and provides basic information about each one such as the owner and availability.

pub async fn get(&self, model_id: &str) -> Result<Model, APIError>

Retrieves a model instance, providing basic information about the model such as the owner and permissioning.

pub async fn delete(&self, model_id: &str) -> Result<DeletedObject, APIError>

Delete a fine-tuned model. You must have the Owner role in your organization to delete a model.