pub enum EmbeddingInput {
String(String),
StringArray(Vec<String>),
IntegerArray(Vec<u32>),
IntegerArrayArray(Vec<Vec<u32>>),
}Variants
String(String)
The string that will be turned into an embedding.
StringArray(Vec<String>)
The array of strings that will be turned into an embedding.
IntegerArray(Vec<u32>)
The array of integers that will be turned into an embedding.
IntegerArrayArray(Vec<Vec<u32>>)
The array of arrays containing integers that will be turned into an embedding.