pub struct VectorStore {
pub id: String,
pub object: String,
pub created_at: u32,
pub name: Option<String>,
pub usage_bytes: u64,
pub file_counts: VectorStoreFileCounts,
pub status: VectorStoreStatus,
pub expires_after: Option<VectorStoreExpirationAfter>,
pub expires_at: Option<u32>,
pub last_active_at: Option<u32>,
pub metadata: Option<HashMap<String, String>>,
}Fields
id: StringThe identifier, which can be referenced in API endpoints.
object: StringThe object type, which is always vector_store.
created_at: u32The Unix timestamp (in seconds) for when the vector store was created.
name: Option<String>The name of the vector store.
usage_bytes: u64The total number of bytes used by the files in the vector store.
file_counts: VectorStoreFileCountsThe number of files in the vector store per status.
status: VectorStoreStatusThe status of the vector store.
expires_after: Option<VectorStoreExpirationAfter>The expiration policy for a vector store.
expires_at: Option<u32>The Unix timestamp (in seconds) for when the vector store will expire.
last_active_at: Option<u32>The Unix timestamp (in seconds) for when the vector store was last active.
metadata: Option<HashMap<String, String>>Set of 16 key-value pairs that can be attached to an object.